# react-test-context-provider

A function that allows you to specify context to pass to a child component (intended for testing only).

## Installation

This module is distributed via [npm][npm] which is bundled with [node][node] and should
be installed as one of your project's `devDependencies`:

```
npm install --save-dev react-test-context-provider
```

## Usage

```javascript
var getContextProvider = require('react-test-context-provider')
var contextObject = {color: 'blue'} // the context you want to provide to the children components
var getElementWithContext = getContextProvider(contextObject) // returns a function you can call any number of times which will always use the given context
var reactElement = getElementWithContext(<ComponentThatNeedsContext />) // returns the react element that results from rendering the given component with the context
```

In this example, I'm using the [Jest](http://facebook.github.io/jest/) testing framework.

**Button.js**

```javascript
import React, {PropTypes} from 'react'
export default function Button({children}, {color}) {
  // function components receive context as the second argument
  return <button style={{background: color}}>{children}</button>
}
Button.propTypes = {children: PropTypes.any.isRequired}
Button.contextTypes = {color: PropTypes.string}
```

**Button.test.js**

```javascript
import React from 'react'
import renderer from 'react-test-renderer'
import getContextProvider from 'react-test-context-provider'
import Button from './Button'

test('styles the button with a background of the context color', () => {
  const getElementWithBlueColorContext = getContextProvider({color: 'blue'})
  const element = getElementWithBlueColorContext(<Button>Click Me</Button>)
  const component = renderer.create(element)
  expect(component).toMatchSnapshot()
})
```

## LICENSE

MIT

[npm]: https://www.npmjs.com/
[node]: https://nodejs.org
